#include <stdint.h>


/* ZADANI:
 * Vasim ukolem je:
 * 1) vytvorit strukturu hsv_image, ktera ponese informace o obrazku
 *     (jmeno souboru, sirka, vyska, data),
 * 2) naplnit ji daty z obrazku (viz format nize), vsechny obrazky ulozit do kontejneru
 * 3) setridit obrazky podle poctu pixelu,
 * 4) transformovat barevny prostor obrazku z HSV do RGB
 * 5) ulozit transformovany obrazek (ukladate pouze jednotlive pixely) do souboru s nazvem
 *     <poradi obrazku v kontejneru>_<sirka>x<vyska>_<puvodni nazev>.rgb
 *
 * - pro konverzi barevneho prostoru pixelu pouzijte dodanou funkci hsv_to_rgb
 * - obrazky, ktere ma program zpracovavat dostava jako argumenty prikazove radky (vicero najednou)
 * - pro overeni spravnosti vystupu vasich dat:
 *   # ls -ail ./
 *   bude vypisovat velikost rgb o presne 8B mensi nez predloha (vysledek nema hlavicku)
 *   # display -s <sirka>x<vyska> -depth 8 rgb:<soubor s vysledkem>
 *   bude vypadat jako neco co byste meli znat
 *
 * VYUZIJTE:
 * - alespon 1x funktor vlastni vyroby
 * - alespon 1 druh kontejneru
 * - alespon 1 funkci z <algorithm>
 *
 * FORMAT NACITANYCH DAT:
 * Kazdy z dodanych souboru obsahuje obrazek, ulozeny v nasledujicim formatu:
 * <4B identifikace - znaky 'h', 's', 'v', '\0'>
 * <2B sirka obrazku - big endian>
 * <2B vyska obrazku - big endian>
 * [<3B pixel>+]
 *  - kde pixel tvori 3B v poradi slozek H <1B>, S <1B>, V <1B>
 *
 * FORMAT UKLADANYCH DAT:
 * Zpracovane obrazky ukladejte ve formatu:
 * [<3B pixel>+]
 *  - kde pixel tvori 3B v poradi slozek R <1B>, G <1B>, B <1B>
 *
 **/

void hsv_to_rgb(uint8_t & h0, uint8_t & s0, uint8_t & v0){
    float h = h0; h /= 255; h*= 360;
    float s = s0; s /= 255;
    float v = v0; v /= 255;

    float tmp_hi = h; int hi = 0;
    while (tmp_hi >= 60){ ++hi; tmp_hi -= 60; }

    float f = h/60 - hi;
    float p = v*(1-s);
    float q = v*(1-f*s);
    float t = v*(1-(1-f)*s);

    hi %= 6;

    v *= 255; t *= 255; p *= 255; q *= 255;

    switch (hi){
        case 0: h0 = v; s0 = t; v0 = p; break;
        case 1: h0 = q; s0 = v; v0 = p; break;
        case 2: h0 = p; s0 = v; v0 = t; break;
        case 3: h0 = p; s0 = q; v0 = v; break;
        case 4: h0 = t; s0 = p; v0 = v; break;
        case 5: h0 = v; s0 = p; v0 = q; break;
    }
}

int main(int argc, char ** argv){

    return 0;
}
